Palmiche. Caballo de guerra
===========================

|logo|

.. list-table::
    :widths: 12 35

    * - **Documentation**
      - |docs|

Description
-----------

This package is a product of my PhD scripting needs.
It is not meant to be (for now) a proper python package with as
few bugs as possible and reaching compatibility in a lot of ecosystems.
However, I am continually updating it and making more and more clear documentation,
therefore you could find some inspiration on my code to create your own scripts,
(as well as I did on many other codes to create **Palmiche**).

Nevertheless, all your ideas and suggestions are very welcome and for sure I will take them into account to improve **Palmiche**.

What for?
~~~~~~~~~

**Palmiche** is a group of scripts that could be used for Molecular Dynamic simulations (launch and analysis), docking and other chemoinformatic operations.
The idea is automate the whole pipeline and improve productivity and transferability.

Documentation
-------------

The installation instructions, documentation and tutorials can be found online on `ReadTheDocs <https://palmiche.readthedocs.io/en/latest/>`_.

Issues
------

If you have found a bug, please open an issue on the `GitHub Issues <https://github.com/ale94mleon/palmiche/issues>`_.

Discussion
----------

If you have questions on how to use **Palmiche**, or if you want to give feedback or share ideas and new features, please head to the `GitHub Discussions <https://github.com/ale94mleon/palmiche/discussions>`_.

Citing **Palmiche**
-------------------

Please refer to the `citation page <https://palmiche.readthedocs.io/en/latest/source/citations.html>`__ on the documentation.

..  |logo|  image:: https://github.com/ale94mleon/palmiche/blob/main/logo/logo.jpg?raw=true
    :target: https://github.com/ale94mleon/palmiche/
    :alt: logo
.. |docs| image:: https://readthedocs.org/projects/palmiche/badge/?version=latest
    :target: https://palmiche.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status